COMMENT
dsyn.mod

dsyn is a "distributed conductance" that is intended to be driven 
by an external function that generates a waveform that follows the
time course of the synaptic conductance.  If that waveform has 
peak amplitude 1, then gbar_dsyn specifies the peak synaptic 
conductance.

x is driven by means of a setpointer statement that links it
to a variable generated by a POINT_PROCESS
ENDCOMMENT

NEURON {
  SUFFIX dsyn
  NONSPECIFIC_CURRENT i
  GLOBAL x : driven by an external function
  RANGE gbar, e
  RANGE g, i
}

UNITS {
  (mV) = (millivolt)
  (S) = (siemens)
  (mA) = (milliamp)
}

PARAMETER {
  e = 0 (mV)
  gbar = 1e-4 (S/cm2)
}

ASSIGNED {
  x (1)
  v (mV)
  g (S/cm2)
  i (mA/cm2)
}

INITIAL {
: printf("Initializing dsyn\n")
  g = gbar*x
  i = g*(v-e)
}

BREAKPOINT {
: printf("dsyn\n\n")
  g = gbar*x
  i = g*(v-e)
}
